%bcond_with    groovy
%bcond_without snakeyaml

Name:           testng
Version:        6.14.3
Release:        %mkrel 4
Group:          Development/Java
Summary:        Java-based testing framework
License:        ASL 2.0
URL:            http://testng.org/
# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz

# Allows building with maven instead of gradle
Source1:        pom.xml

# Remove bundled binaries to make sure we don't ship anything forbidden
Source2:        generate-tarball.sh

Patch0:         0001-Avoid-accidental-javascript-in-javadoc.patch
Patch1:         0002-Replace-bundled-jquery-with-CDN-link.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(com.beust:jcommander)
BuildRequires:  mvn(com.google.inject:guice)
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache-extras.beanshell:bsh)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.sonatype.oss:oss-parent:pom:)
%if %{with groovy}
BuildRequires:  mvn(org.assertj:assertj-core) >= 3.8.0
BuildRequires:  mvn(org.codehaus.gmavenplus:gmavenplus-plugin)
BuildRequires:  mvn(org.codehaus.groovy:groovy-all)
BuildRequires:  mvn(org.spockframework:spock-core)
%endif
%if %{with snakeyaml}
BuildRequires:  mvn(org.yaml:snakeyaml)
%endif

%description
TestNG is a testing framework inspired from JUnit and NUnit but introducing
some new functionality, including flexible test configuration, and
distributed test running.  It is designed to cover unit tests as well as
functional, end-to-end, integration, etc.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q

%patch0 -p1
%patch1 -p1

cp %{SOURCE1} .

# remove any bundled libs, but not test resources
find ! -path "*/test/*" -name *.jar -print -delete
find -name *.class -delete

# these are unnecessary
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin

%if %{without snakeyaml}
%pom_remove_dep org.yaml:snakeyaml
rm src/main/java/org/testng/internal/Yaml*.java
rm src/main/java/org/testng/Converter.java
%endif

# missing test deps
%if %{with groovy}
%pom_add_plugin "org.codehaus.gmavenplus:gmavenplus-plugin" pom.xml \
  "<executions><execution><goals><goal>addTestSources</goal><goal>testGenerateStubs</goal><goal>testCompile</goal><goal>removeTestStubs</goal></goals></execution></executions>"
%pom_add_dep "org.assertj:assertj-core::test"
%pom_add_dep "org.spockframework:spock-core::test"
%pom_add_dep "org.codehaus.groovy:groovy-all::test"

# java.lang.NoClassDefFoundError: net/sf/cglib/proxy/CallbackFilter when executing tests
%pom_add_dep "net.sf.cglib:cglib::test"
%endif

sed -i -e 's/DEV-SNAPSHOT/%{version}/' src/main/java/org/testng/internal/Version.java

cp -p ./src/main/java/*.dtd.html ./src/main/resources/.

%mvn_file : %{name}
# jdk15 classifier is used by some other packages
%mvn_alias : :::jdk15:

%build
%if %{with groovy} && %{with snakeyaml}
# A couple of parallelisation tests are *sometimes* failing, so let's ignore failures
# because they do complete successfully most of the time
%mvn_build -- -Dmaven.test.failure.ignore=true
%else
%mvn_build -f
%endif

%install
%mvn_install

%files -f .mfiles
%doc CHANGES.txt README.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt




%changelog
* Sat Feb 15 2020 umeabot <umeabot> 6.14.3-4.mga8
+ Revision: 1527753
- Mageia 8 Mass Rebuild

* Wed Jul 24 2019 daviddavid <daviddavid> 6.14.3-3.mga8
+ Revision: 1423787
- Disable groovy support by default
- Fix test suite execution

* Fri Sep 21 2018 umeabot <umeabot> 6.14.3-2.mga7
+ Revision: 1291755
- Mageia 7 Mass Rebuild

* Sun Aug 26 2018 daviddavid <daviddavid> 6.14.3-1.mga7
+ Revision: 1254527
- new version: 6.14.3 (sync with fc29)

* Sat Apr 30 2016 daviddavid <daviddavid> 6.9.10-1.mga6
+ Revision: 1008285
- Update to 6.9.10
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 6.9.9-2.mga6
+ Revision: 978197
- First rebuild of the java stack
- sync package testng with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Dec 30 2014 daviddavid <daviddavid> 6.8.7-6.mga5
+ Revision: 807202
- rebuild for new sonatype-oss-parent

* Wed Oct 15 2014 umeabot <umeabot> 6.8.7-5.mga5
+ Revision: 745216
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 6.8.7-3.mga4
+ Revision: 535777
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 dmorgan <dmorgan> 6.8.7-2.mga4
+ Revision: 482579
- Rebuild against new javapackages
- New version

* Fri Mar 01 2013 dmorgan <dmorgan> 6.8-1.mga3
+ Revision: 400734
- New version

* Mon Jan 14 2013 umeabot <umeabot> 6.0.1-2.mga3
+ Revision: 384415
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 10 2011 gil <gil> 6.0.1-1.mga2
+ Revision: 166107
- New version

* Wed Jan 19 2011 dmorgan <dmorgan> 5.11-1.mga1
+ Revision: 23746
- Fix release
- Add missing file
- New version ( fedora )
- imported package testng


* Thu Jan 15 2009 Götz Waschk <waschk@mandriva.org> 0:5.8-2.0.2mdv2009.1
+ Revision: 329848
- fix postun script

* Thu Aug 07 2008 Thierry Vignaud <tvignaud@mandriva.com> 0:5.8-2.0.1mdv2009.0
+ Revision: 265755
- rebuild early 2009.0 package (before pixel changes)

* Wed Apr 23 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:5.8-0.0.1mdv2009.0
+ Revision: 196814
- new version

* Thu Feb 07 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:5.6-1.0.1mdv2008.1
+ Revision: 163756
- rebuild

* Sat Jan 26 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:5.6-0.0.1mdv2008.1
+ Revision: 158300
- import testng


